@@ -30,8 +30,13 @@ def retrieve_authorization_header_value() -> str:
 
     vinci_auth_path = retrieve_folder_of_vinci_auth(user)
 
+    path_to_file=f"{vinci_auth_path}\\{TOKEN_FILE_NAME}"
+
+    if not os.path.exists(path_to_file):
+        raise Exception("TOKEN_NOT_FOUND")
+
     token = ""
-    with open(f"{vinci_auth_path}\\{TOKEN_FILE_NAME}", 'r') as f:
+    with open(path_to_file, 'r') as f:
         token = f.readline()
 
     return f"Basic {token}"
